@@ -211,13 +211,13 @@ class PreseemGrpcClient(object):
                     return x
             except grpc.RpcError as err:
                 logging.debug('Error calling service: %s (%s)', err.code(), err.details())
-                if err.code() in (grpc.StatusCode.INTERNAL, grpc.StatusCode.NOT_FOUND, grpc.StatusCode.UNKNOWN, grpc.StatusCode.UNIMPLEMENTED):
+                if err.code() in (grpc.StatusCode.INTERNAL, grpc.StatusCode.NOT_FOUND, grpc.StatusCode.UNKNOWN, grpc.StatusCode.UNIMPLEMENTED, grpc.StatusCode.INVALID_ARGUMENT):
                     raise
                 if retry_num == num_retries:
                     logging.warning('Error calling service: %s (%s)', err.code(), err.details())
                     raise
             except Exception as e:
-                logging.warning('Error calling service: %s', e)
+                logging.warning('%s error calling service: %s', type(e).__name__, e)
                 if retry_num == num_retries:
                     logging.exception('Error calling grpc service')
                     raise
